==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeEntity.h <==
// class gnu.xml.libxmlj.dom.GnomeEntity

// class file dependencies
// @dep_class 49f16c5f00236c4e gnu_xml_libxmlj_dom_GnomeEntity
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeEntity_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeEntity_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$refs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object	_jc_gnu_xml_libxmlj_dom_GnomeEntity$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeEntity$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getInputEncoding$546bf75c8cbcf14f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getNotationName$189660d5e1b465b0(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getXmlEncoding$4566fbb694fdecf9(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getXmlVersion$e238523151d504aa(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getInputEncoding$546bf75c8cbcf14f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getNotationName$189660d5e1b465b0;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getXmlEncoding$4566fbb694fdecf9;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getXmlVersion$e238523151d504aa;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods {
	struct _jc_java_lang_String$object	*(*getInputEncoding$546bf75c8cbcf14f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
	struct _jc_java_lang_String$object	*(*getNotationName$189660d5e1b465b0)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
	struct _jc_java_lang_String$object	*(*getXmlEncoding$4566fbb694fdecf9)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
	struct _jc_java_lang_String$object	*(*getXmlVersion$e238523151d504aa)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods	gnu_xml_libxmlj_dom_GnomeEntity;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs	gnu_xml_libxmlj_dom_GnomeEntity;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeEntity;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object {
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype _jc_gnu_xml_libxmlj_dom_GnomeEntity$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeEntity, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeEntity$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeEntity_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeEntity.h <==
// class gnu.xml.libxmlj.dom.GnomeEntity

// class file dependencies
// @dep_class 49f16c5f00236c4e gnu_xml_libxmlj_dom_GnomeEntity
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeEntity_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeEntity_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$refs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object	_jc_gnu_xml_libxmlj_dom_GnomeEntity$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeEntity$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getInputEncoding$546bf75c8cbcf14f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getNotationName$189660d5e1b465b0(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getXmlEncoding$4566fbb694fdecf9(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$getXmlVersion$e238523151d504aa(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeEntity$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getInputEncoding$546bf75c8cbcf14f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getNotationName$189660d5e1b465b0;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getXmlEncoding$4566fbb694fdecf9;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$getXmlVersion$e238523151d504aa;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeEntity$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods {
	struct _jc_java_lang_String$object	*(*getInputEncoding$546bf75c8cbcf14f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNotationName$189660d5e1b465b0)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getXmlEncoding$4566fbb694fdecf9)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getXmlVersion$e238523151d504aa)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vmethods	gnu_xml_libxmlj_dom_GnomeEntity;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_refs	gnu_xml_libxmlj_dom_GnomeEntity;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeEntity$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeEntity;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntity$object {
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeEntity$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeEntity$vtype _jc_gnu_xml_libxmlj_dom_GnomeEntity$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeEntity, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeEntity$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeEntity_H_ */
